@@ -84,14 +84,14 @@ class Energidataservice:
                 (k, datetime.strptime(v, '%Y-%m-%dT%H:%M:%S')) for k, v in d.items() if (k in ['HourUTC', 'HourDK'] and v))
         return indata_json
 
-    @staticmethod
-    def forecasts_df(area, start_date=datetime(2020, 1, 1), end_date=datetime(2030, 12, 31)):
-        import pandas as pd
-        indata_list = Energidataservice.forecasts(area, start_date, end_date)
-        df = pd.DataFrame(indata_list)
-        df = df.pivot_table(index='HourUTC')
-        df = df.ffill()
-        return df
+    # @staticmethod
+    # def forecasts_df(area, start_date=datetime(2020, 1, 1), end_date=datetime(2030, 12, 31)):
+    #     import pandas as pd
+    #     indata_list = Energidataservice.forecasts(area, start_date, end_date)
+    #     df = pd.DataFrame(indata_list)
+    #     df = df.pivot_table(index='HourUTC', columns='forecast')
+    #     df = df.ffill()
+    #     return df
 
     @staticmethod
     def forecasts(area, start_date=datetime(2020, 1, 1), end_date=datetime(2030, 12, 31)):
@@ -99,7 +99,7 @@ class Energidataservice:
         end_date_str = (end_date + timedelta(days=1)).strftime("%Y-%m-%dT00:00")
         base_url = f"https://api.energidataservice.dk/dataset/Forecasts_Hour?offset=0"
         url = f"{base_url}&start={start_date_str}&end={end_date_str}"
-        print(url)
+        # print(url)
         indata_json = requests.get(url).json()['records']
         indata_json = [obs for obs in indata_json if obs['PriceArea'] == area]
         for d in indata_json:
